package de.beagtex.gui;

import java.awt.Event;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

import de.beagtex.listener.control.CopyListener;
import de.beagtex.listener.control.CutListener;
import de.beagtex.listener.control.ExitListener;
import de.beagtex.listener.control.NewListener;
import de.beagtex.listener.control.PasteListener;
import de.beagtex.listener.control.RedoListener;
import de.beagtex.listener.control.SaveAsListener;
import de.beagtex.listener.control.SaveListener;
import de.beagtex.listener.control.SelectAllListener;
import de.beagtex.listener.control.SearchListener;
import de.beagtex.listener.control.UndoListener;
import de.beagtex.listener.format.BoldListener;
import de.beagtex.listener.format.ColordefListener;
import de.beagtex.listener.format.ItalicListener;
import de.beagtex.listener.format.LeftListener;
import de.beagtex.listener.format.RightListener;
import de.beagtex.listener.format.StandardColordefListener;
import de.beagtex.listener.format.UnderlineListener;
import de.beagtex.listener.format.CenteredListener;
import de.beagtex.listener.gui.InfoListener;
import de.beagtex.listener.gui.OpenButtonListener;
import de.beagtex.listener.insert.CrossRefLabelListener;
import de.beagtex.listener.insert.CrossRefPagereferenceListener;
import de.beagtex.listener.insert.CrossRefReferenceListener;
import de.beagtex.listener.insert.FigureListener;
import de.beagtex.listener.insert.AutoIndexListener;
import de.beagtex.listener.insert.BulletListener;
import de.beagtex.listener.insert.CaptionAboveListener;
import de.beagtex.listener.insert.CaptionListener;
import de.beagtex.listener.insert.FootnoteListener;
import de.beagtex.listener.insert.GraphicListener;
import de.beagtex.listener.insert.IndexInsertListener;
import de.beagtex.listener.insert.IndexingListerner;
import de.beagtex.listener.insert.ContentListener;
import de.beagtex.listener.insert.LatexListener;
import de.beagtex.listener.insert.EmptyPageListener;
import de.beagtex.listener.insert.MarginNoteListener;
import de.beagtex.listener.insert.NumberedListener;
import de.beagtex.listener.insert.ChangeoverListener;
import de.beagtex.listener.insert.TableListener;
import de.beagtex.listener.insert.TableListListener;
import de.beagtex.listener.insert.QuotationListener;

/**
 * Main-Menu-Bar. Here all menu-options are realized. A Menu has to be
 * integrated into a existing BFrame.
 * 
 * @author Benjamin Haag
 * 
 */
public class MainMenu extends JMenuBar {

	/**
	 * serialVersionUID
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor: a BFrame for the menu is needed
	 * 
	 * @param pBFrame :
	 *            the related BFrame
	 */
	public MainMenu(BFrame pBFrame) {
		// File-Menu
		JMenu file = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.file"));
		JMenuItem newI = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.new"));
		setCtrlAccelerator(newI, 'N');
		newI.addActionListener(new NewListener(pBFrame, false));
		JMenuItem open = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.open"));
		setCtrlAccelerator(open, 'O');
		open.addActionListener(new OpenButtonListener(pBFrame.getEdit()));
		JMenuItem save = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.save"));
		setCtrlAccelerator(save, 'S');
		save.addActionListener(new SaveListener(pBFrame.getEdit()));
		JMenuItem saveAs = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.saveas"));
		saveAs.addActionListener(new SaveAsListener(pBFrame.getEdit()));
		JMenuItem export = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.export"));
		export.setEnabled(false);
		JMenuItem close = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.close"));
		close.addActionListener(new ExitListener(pBFrame.getEdit()));
		setCtrlAccelerator(close, 'Q');
		close.setEnabled(false);
		JMenuItem exit = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.file.exit"));
		exit.addActionListener(new ExitListener(pBFrame.getEdit()));
		file.add(newI);
		file.add(open);
		file.add(close);
		file.addSeparator();
		file.add(save);
		file.add(saveAs);
		file.add(export);
		file.addSeparator();
		file.add(exit);
		// setContentPane(datei);
		// Edit-Menu
		JMenu editMenu = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit"));
		JMenuItem undoM = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.undo"));
		setCtrlAccelerator(undoM, 'Z');
		undoM.addActionListener(new UndoListener(pBFrame.getEdit()));
		JMenuItem redo = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.redo"));
		setCtrlAccelerator(redo, 'Y');
		redo.addActionListener(new RedoListener(pBFrame.getEdit()));
		JMenuItem cut = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.cut"));
		setCtrlAccelerator(cut, 'X');
		cut.addActionListener(new CutListener(pBFrame.getEdit()));
		JMenuItem copy = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.copy"));
		setCtrlAccelerator(copy, 'C');
		copy.addActionListener(new CopyListener(pBFrame.getEdit()));
		JMenuItem paste = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.paste"));
		setCtrlAccelerator(paste, 'V');
		paste.addActionListener(new PasteListener(pBFrame.getEdit()));
		JMenuItem search = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.search"));
		setCtrlAccelerator(search, 'F');
		search.addActionListener(new SearchListener(pBFrame.getEdit()));
		JMenuItem selAll = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.edit.select"));
		setCtrlAccelerator(selAll, 'A');
		selAll.addActionListener(new SelectAllListener(pBFrame.getEdit()));
		editMenu.add(undoM);
		editMenu.add(redo);
		editMenu.addSeparator();
		editMenu.add(cut);
		editMenu.add(copy);
		editMenu.add(paste);
		editMenu.addSeparator();
		editMenu.add(search);
		editMenu.add(selAll);

		// Format-Menu
		JMenu format = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.format"));
		JMenuItem bold = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.bold"));
		bold.addActionListener(new BoldListener(pBFrame.getEdit()));
		setCtrlAccelerator(bold, 'B');
		JMenuItem italic = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.italic"));
		italic.addActionListener(new ItalicListener(pBFrame.getEdit()));
		setCtrlAccelerator(italic, 'I');
		JMenuItem underline = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.underline"));
		underline.addActionListener(new UnderlineListener(pBFrame.getEdit()));
		setCtrlAccelerator(underline, 'U');
		JMenu alignment = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.alignment"));
		JMenuItem left = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.alignment.left"));
		left.addActionListener(new LeftListener(pBFrame.getEdit()));
		JMenuItem centered = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.alignment.centered"));
		centered.addActionListener(new CenteredListener(pBFrame.getEdit()));
		JMenuItem right = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.alignment.right"));
		right.addActionListener(new RightListener(pBFrame.getEdit()));
		JMenuItem colorDef = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.colordef"));
		colorDef.addActionListener(new ColordefListener(pBFrame.getEdit()));
		JMenuItem indexing = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.indexing"));
		indexing.addActionListener(new IndexingListerner(pBFrame.getEdit()));
		setCtrlAccelerator(indexing, 'D');
		JMenuItem autoIndix = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.format.autoindexing"));
		autoIndix.addActionListener(new AutoIndexListener(pBFrame.getEdit()));
		format.add(bold);
		format.add(italic);
		format.add(underline);
		alignment.add(left);
		alignment.add(centered);
		alignment.add(right);
		// setContentPane(ausrichtung);
		format.add(alignment);
		format.add(colorDef);
		format.add(indexing);
		format.add(autoIndix);

		// Insert-Menu
		JMenu insert = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert"));
		JMenu pageing = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.manualchangeover"));
		JMenuItem changeover = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.manualchangeover.changeover"));
		setCtrlAccelerator(changeover, 'P');
		changeover.addActionListener(new ChangeoverListener(pBFrame
				.getEdit()));
		JMenuItem emptyPage = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.manualchangeover.emptypage"));
		emptyPage.addActionListener(new EmptyPageListener(pBFrame.getEdit()));
		pageing.add(changeover);
		pageing.add(emptyPage);
		// setContentPane(wechsel);
		JMenu graphics = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.graphics"));
		JMenuItem graphicIn = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.graphics.insert"));
		graphicIn.addActionListener(new GraphicListener(pBFrame.getEdit()));
		JMenu graphCaption = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.graphics.caption"));
		JMenuItem graphCaptAbove = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.graphics.caption.above"));
		graphCaptAbove.addActionListener(new CaptionAboveListener(pBFrame
				.getEdit()));
		JMenuItem graphCaptBeneath = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.graphics.caption.beneath"));
		graphCaptBeneath.addActionListener(new CaptionListener(pBFrame
				.getEdit()));
		graphCaption.add(graphCaptAbove);
		graphCaption.add(graphCaptBeneath);
		// setContentPane(grafBeschriftung);
		graphics.add(graphicIn);
		graphics.add(graphCaption);
		// setContentPane(grafik);
		JMenu table = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.table"));
		JMenuItem tableIn = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.table.insert"));
		tableIn.addActionListener(new TableListener(pBFrame.getEdit()));
		JMenu tabCaption = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.table.caption"));
		JMenuItem tabCaptAbove = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.table.caption.above"));
		tabCaptAbove.addActionListener(new CaptionAboveListener(pBFrame
				.getEdit()));
		JMenuItem tabCaptBeneath = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.table.caption.beneath"));
		tabCaptBeneath
				.addActionListener(new CaptionListener(pBFrame.getEdit()));
		tabCaption.add(tabCaptAbove);
		tabCaption.add(tabCaptBeneath);

		table.add(tableIn);
		table.add(tabCaption);

		JMenuItem quotation = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.quotation"));
		quotation.addActionListener(new QuotationListener(pBFrame.getEdit()));
		JMenuItem latex = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.latexfile"));
		latex.addActionListener(new LatexListener(pBFrame.getEdit()));
		JMenu listing = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.listings"));
		JMenuItem standard = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.listings.standard"));
		standard.addActionListener(new BulletListener(pBFrame.getEdit()));
		JMenuItem numbered = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.listings.numbered"));
		numbered.addActionListener(new NumberedListener(pBFrame.getEdit()));
		JMenuItem footnote = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.footnote"));
		footnote.addActionListener(new FootnoteListener(pBFrame.getEdit()));
		JMenuItem standardColors = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.standardcolordef"));
		standardColors.addActionListener(new StandardColordefListener(pBFrame
				.getEdit()));
		listing.add(standard);
		listing.add(numbered);

		JMenu registers = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.registers"));
		JMenuItem content = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.registers.toc"));
		content.addActionListener(new ContentListener(pBFrame.getEdit()));
		JMenuItem figures = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.registers.lof"));
		figures
				.addActionListener(new FigureListener(pBFrame.getEdit()));
		JMenuItem tables = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.registers.lot"));
		tables.addActionListener(new TableListListener(pBFrame.getEdit()));
		JMenuItem index = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.registers.index"));
		index.addActionListener(new IndexInsertListener(pBFrame.getEdit()));
		registers.add(content);
		registers.add(figures);
		registers.add(tables);
		registers.add(index);		
		JMenuItem marginnote = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.marginnote"));
		marginnote.addActionListener(new MarginNoteListener(pBFrame.getEdit()));
		JMenu crossref = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.crossref"));
		JMenuItem label = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.crossref.label"));
		label.addActionListener(new CrossRefLabelListener(pBFrame.getEdit()));
		JMenuItem reference = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.crossref.reference"));
		reference.addActionListener(new CrossRefReferenceListener(pBFrame.getEdit()));
		JMenuItem pagereference = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.insert.crossref.pagereference"));
		pagereference.addActionListener(new CrossRefPagereferenceListener(pBFrame.getEdit()));
		crossref.add(label);
		crossref.add(reference);
		crossref.add(pagereference);
	
		insert.add(pageing);
		insert.add(graphics);
		insert.add(table);
		insert.add(quotation);
		insert.add(latex);
		insert.add(listing);
		insert.add(footnote);
		insert.add(standardColors);
		insert.add(registers);
		insert.add(marginnote);
		insert.add(crossref);

		// //Help-Menu
		JMenu hilfe = new JMenu(BFrame.get_prop().getProperty(
		 "beagtex.menu.help"));
		JMenuItem docu = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.help.docu"));
		docu.setVisible(false);
		JMenuItem info = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.help.info"));
		info.addActionListener(new InfoListener(pBFrame.getEdit(), "Info"));
		JMenuItem credits = new JMenuItem(BFrame.get_prop().getProperty(
		 "beagtex.menu.help.credits"));
		credits
				.addActionListener(new InfoListener(pBFrame.getEdit(),
						"Credits"));
		hilfe.add(docu);
		hilfe.add(info);
		hilfe.add(credits);
		// setContentPane(hilfe);

		add(file);
		add(editMenu);
		add(format);
		add(insert);
		add(hilfe);
		// setContentPane(pMenue);
	}

	/**
	 * Methode zur Bereitstellung der Ctrl-Tastenkombinationen
	 * 
	 * @param acc:
	 *            Tastaturzeichen
	 * @param mi:
	 *            MenuItem
	 */
	private void setCtrlAccelerator(JMenuItem mi, char acc) {

		KeyStroke ks = KeyStroke.getKeyStroke(acc, Event.CTRL_MASK);
		mi.setAccelerator(ks);
	}
}
